@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 #----------------------------------------------------------------------------
 
@@ -387,11 +387,11 @@ sub _check_deprecated {
         }
     }
 
-    if($elem && $elem != $tag->[0]) {
+    if($elem && $elem->[0] ne $tag->[0]) {
         push @{ $self->{ERRORS} }, {
             #ref     => 'Best Practices Recommedation only',
             error   => "C011",
-            message => "<$tag->[0]> has been deprecated in favour of <$elem>",
+            message => "<$tag->[0]> has been deprecated in favour of <$elem->[0]>",
             row     => $tag->[4],
             col     => $tag->[5]
         };
@@ -600,7 +600,7 @@ L<HTML::TokeParser>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2008-2013 Barbie for Miss Barbell Productions.
+  Copyright (C) 2008-2015 Barbie for Miss Barbell Productions.
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
