@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 #----------------------------------------------------------------------------
 
@@ -72,7 +72,7 @@ my @IGNORE = (
     qr/\.(xml|txt|pdf|doc|odt|odp|ods)$/i,
     qr/\.(tgz|gz|bz2|rar|zip)$/i,
     qr/\.(mp4|avi|wmv)$/i,
-    qr/\.(jpg|bmp|gif|png)$/i,
+    qr/\.(jpg|jpeg|bmp|gif|png|tiff?)$/i,
 );
 
 my @RESULTS = qw( PAGES PASS FAIL NET );
@@ -552,7 +552,7 @@ L<XML::LibXML>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2008-2013 Barbie for Miss Barbell Productions.
+  Copyright (C) 2008-2015 Barbie for Miss Barbell Productions.
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
